#
# spec file for package python-knack
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-knack
Version:        0.7.2
Release:        lp152.3.3.1
Summary:        A Command-Line Interface framework
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/microsoft/knack
Source:         https://files.pythonhosted.org/packages/source/k/knack/knack-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module argcomplete}
BuildRequires:  %{python_module colorama}
BuildRequires:  %{python_module jmespath}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module tabulate}
BuildRequires:  %{python_module vcrpy}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-argcomplete
Requires:       python-colorama
Requires:       python-jmespath
Requires:       python-pygments
Requires:       python-six
Requires:       python-tabulate
BuildArch:      noarch
%python_subpackages

%description
A Command-Line Interface framework

%prep
%setup -q -n knack-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Dec 14 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Tue Aug 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.2
  * [Config] Support listing sections (#217)
* Tue Jun 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.7.1
  * Rollback `get_config_parser` in `config.py` (#205)
- from version 0.7.0
  * Add a `default_value_source` property in `HelpParameter` (#202)
  * Support removing option/section from config file (#201)
  * Support writing comment to config file (#201)
  * Import `configparser` directly instead of from `six` (#201)
  * Drop `get_config_parser` function from `config.py` (#201)
- Remove workaround for version number in spec file
* Thu May  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.7.0rc4
  * Change the timing to raise `EVENT_CLI_POST_EXECUTE` event (#199)
  * Make `CLI.invoke` catch `SystemExit` (#199)
- from version 0.7.0rc3
  * Change experimental tag color to cyan (#196)
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove patch as the test fail properly as the pkg does not support
  python2:
  * k_skip-broken-tests.patch
- Fix the version field
* Thu Apr  2 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.7.0rc1
  * Allow disabling color (#171)
  * Support yaml and yamlc output (#173)
  * Drop support for python 2 and 3.5 (#174)
  * Support --only-show-errors to disable warnings (#179)
  * Add experimental tag (#180)
- Add patch to skip two tests that currently fail on openSUSE
  * k_skip-broken-tests.patch
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.3:
  * Fixes issue where argument marked is_preview=True would not always be handled correctly.
  * Fixes issue where ensuring a directory exists could cause a race condition.
* Fri May 24 2019 pgajdos@suse.com
- version update to 0.6.2
  * Adds ability to declare that command groups, commands, and arguments
  are in a preview status and therefore might change or be removed.
  This is done by passing the kwarg `is_preview=True`.
  * Adds a generic `StatusTag` class to `knack.util` that allows you
  to create your own colorized tags like `[Preview]` and `[Deprecated]`.
  * When an incorrect command name is entered, Knack will now attempt
  to suggest the closest alternative.
* Tue May 21 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.1:
  * Always read from local for configured_default
- from version 0.6.0
  * Support local context chained config file
* Fri Apr 12 2019 pgajdos@suse.com
- version update to 0.5.4
  * Allows the loading of text files using @filename syntax.
  * Adds the argument kwarg configured_default to support setting
    argument defaults via the config file's [defaults] section or
    an environment variable.
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.3:
  * Removes an incorrect check when adding arguments.
  * Updates usages of yaml.load to use yaml.safe_load.
  * Fix issue with some scenarios (no args and --version)
  * Adds support for positional arguments with the .positional helper method on ArgumentsContext.
  * Removes the necessity for the type field in help.py. This information can be inferred from the class, so specifying it causes unnecessary crashes.
  * Adds support for examining the result of a command after a call to invoke. The raw object, error (if any) an exit code are accessible.
  * Fixes an issue with the default config directory. It use to be .cli and is now based on the CLI name.
  * Adds ability to specify line width for help text display.
  * Preserves logging verbosity and output format on the namespace for use by validators.
  * Adds ability to set config file name.
  * Fixes bug with argument deprecations.
- Switch to github archive to run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Oct  4 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.4.3
  + Fixes issue where values were sometimes ignored when using
    deprecated options regardless of which option was given.
- from version 0.4.2
  + Bug fixes: [output]: disable number parse on table mode PR #88
- from version 0.4.1
  + Version 0.4.0 introduced deprecation to Knack. This
    release fixes a bug related to that.
  * Ensures that the action kwarg is only set if the item is
    deprecated. Previously it would set it to "None" which
    would then override a pre-existing action like store_true.
  + Version 0.4.0 also added the concept of the command group table
    to the CommandsLoader class. This release corrects an issue
    related to that:
  * The command group table would only be filled by calls to create
    CommandGroup classes. This resulted in some gaps in the command
    group table.
- from version 0.4.0
  + Add mechanism to deprecate commands, command groups,
    arguments and argument options.
  + Improve help display support for Unicode.
- from version 0.3.3
  + expose a callback to let client side perform extra logics (#80)
  + output: don't skip false value on auto-tabulating (#83)
* Wed May  2 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.3.2
  + ArgumentsContext.ignore() should use hidden options_list (#76)
  + Consolidate exception handling (#66)
- Fix bogus comment in spec file
* Thu Feb  8 2018 adrian.glaubitz@suse.com
- Initial release
  + Version 0.3.1
